# 接入准备
## 申请商户ID及获取EidToken
[参考这篇指引](https://cloud.tencent.com/document/product/1007/56643#3.-.E5.86.85.E5.B5.8C.E5.B0.8F.E7.A8.8B.E5.BA.8F-sdk)

## 前置条件
1. 添加服务器域名白名单
   小程序前端接口请求有域名白名单限制，未添加白名单的域名只能在调试模式下运行。您需要在小程序上线前需要将以下域名添加至服务器域名白名单：
    ```javascript
    // request 合法域名
    eid.faceid.qq.com
    eid-enhance.faceid.qq.com
    ```
2. 添加业务域名白名单
在小程序配置业务域名中，将下载后的校验文件发给腾讯侧对接人员，待腾讯侧进行完相应的操作后，将以下域名添加至业务域名白名单：
    ```javascript
    eid.faceid.qq.com
    eid-enhance.faceid.qq.com
    ```


## uni-app接入
### 步骤一：注册并创建 uni-app 开发环境
uni-app开发接入具体参照[uni官网](https://uniapp.dcloud.net.cn/)

### 步骤二：下载并配置mp_ecard_sdk源码
1. [下载sdk源码](https://faceid-ecard-1254418846.cos.ap-chengdu.myqcloud.com/uni/cloud-mp-ecard-uni-sdk-v1.0.0.zip)
2. 配置sdk源码
- 方法一：项目根目录配置（推荐）
	1. 将sdk源码包mp_ecard_sdk文件夹拷贝到项目根目录
	2. 在pages.json中配置相关页面
		```javascript
			"pages": [
						{
              "path": "mp_ecard_sdk/index/index",
              "style": {
                "navigationBarTitleText": "腾讯云E证通授权"
              }
            },
            {
              "path": "mp_ecard_sdk/protocol/eid/eid",
              "style": {
                "navigationBarTitleText": "eID数字身份小程序服务协议",
                "enablePullDownRefresh": false
              }
            },
            {
              "path": "mp_ecard_sdk/protocol/privacy/privacy",
              "style": {
                "navigationBarTitleText": "腾讯隐私政策",
                "enablePullDownRefresh": false
              }
            },
            {
              "path": "mp_ecard_sdk/protocol/service/service",
              "style": {
                "navigationBarTitleText": "腾讯云E证通服务协议",
                "enablePullDownRefresh": false
              }
            },
            {
              "path": "mp_ecard_sdk/protocol/userAccredit/userAccredit",
              "style": {
                "navigationBarTitleText": "用户授权协议",
                "enablePullDownRefresh": false
              }
            }
				]
		```

- 方法二：任意位置文件夹配置
	1. 将sdk源码放置在其他文件夹下，例如pagse/mp_ecard_sdk
	2. 在pages.json中配置相关页面，pages的path应为mp_ecard_sdk的相对位置路径，例如：pagse/
	```javascript
		"pages": [
				{
			      "path": "pages/mp_ecard_sdk/index/index",
            "style": {
              "navigationBarTitleText": "腾讯云E证通授权"
            }
          },
          {
            "path": "pages/mp_ecard_sdk/protocol/eid/eid",
            "style": {
              "navigationBarTitleText": "eID数字身份小程序服务协议",
              "enablePullDownRefresh": false
            }
          },
          {
            "path": "pages/mp_ecard_sdk/protocol/privacy/privacy",
            "style": {
              "navigationBarTitleText": "腾讯隐私政策",
              "enablePullDownRefresh": false
            }
          },
          {
            "path": "pages/mp_ecard_sdk/protocol/service/service",
            "style": {
              "navigationBarTitleText": "腾讯云E证通服务协议",
              "enablePullDownRefresh": false
            }
          },
          {
            "path": "pages/mp_ecard_sdk/protocol/userAccredit/userAccredit",
            "style": {
              "navigationBarTitleText": "用户授权协议",
              "enablePullDownRefresh": false
            }
          }
			],
	```
	3. 修改mp_ecard_sdk下的globalConfig.js的normalPath参数,修改为对应相对路径，例如：'/pages'。注意，开头需要加'/'
	```javascript
		export default  {
			normalPath: '/pages'
		}
	```


3. 初始化
- 方法一：可以在 App.vue  中全局初始化
	```javascript
	import { initEid } from './mp_ecard_sdk/main';
	
	export default {
		onLaunch: function() {
			initEid();
		},
	};
	```
- 方法二：在需要调用到的页面方法之前初识化即可

4. 调用
	在需要进行核身的地方引入调用SDK的方法 startEid

	<b style="color: red">！注意：startEid调用需要在initEid初始化之后</b>

  ```javascript
  import { startEid } from './mp_ecard_sdk/main'

  // 示例方法
  startEid({
            data: {
                token,
            },
            verifyDoneCallback(res) {  
                const { token, verifyDone } = res;
                console.log('收到核身完成的res:', res);
                console.log('核身的token是:', token); 
                console.log('是否完成核身:', verifyDone);          
            },
        });
  ```

startEid() 参数说明: 
- `startEid(options)`：进入实名认证页面。
    - `options`：Object required 接入方传入的参数。	
    - `options.data.token`：String required 接入方小程序从接入方服务端获取EidToken。
    - `options.verifyDoneCallback`：Function(res) required 核身完成的回调。res 包含验证成功的 token，是否完成的布尔值标志 verifyDone。请根据res返回的结果进行业务处理判断。


## 获取E证通核验结果信息
用户完成人脸核身后，会以回调形式返回 EidToken 以及其他信息，接入方小程序将 EidToken 传给接入方的服务端，接入方服务端即可凭借 EidToken 参数调用获取小程序核身结果信息 GetEidResult 接口去获取本次核身的详细信息，最后将核身结果返回给接入方小程序。
（说明：EidToken 作为一次核身流程的标识，有效时间为600秒；完成核身后，可用该标识获取3天内验证结果信息。）


## 卸载sdk
删除`mp_ecard_sdk`文件夹。

## 接入时序图

```mermaid
sequenceDiagram
autonumber
participant A as 接入方小程序
participant B as E证通SDK
participant C as eID数字身份小程序

A->>A: 初始化SDK: initEid() 
A->>B: 调用SDK: startEid()，打开E证通SDK页面
B->>C: 跳转至eID数字身份小程序
C->>C: 核身流程
C->>B: 核身完成，返回接入方小程序E证通SDK页面
B->>B: 监听从eID数字身份小程序返回的事件
B->>A: 回退至接入方小程序调用startEid()的页面，执行接入方传入的回调函数
```

## 注意事项

1. 从eID数字身份小程序返回接入方小程序

当接入方小程序在初始化E证通SDK的时候，E证通SDK会通过 wx.onAppShow 注册一个监听从eID数字身份小程序跳转回接入方小程序的事件，从而根据情况触发接入方传入的核身完成的回调函数
由于微信的机制，用户在eID数字身份小程序跳转回接入方小程序的时候，同时也会触发接入方小程序 app.js 中的 onShow 方法。为了避免冲突，如果接入方小程序在 onShow 中有执行逻辑的话，需要排除掉从eID数字身份小程序跳转回接入方小程序这个场景。

    可通过以下方法实现：
    ```javascript
    // app.vue
    
    onShow(options) {
        const { referrerInfo, scene } = options;
        /* 判断是否从eID数字身份小程序返回 */
        const { appId } = referrerInfo;
        if (scene === 1038 && appId === 'wx0e2cb0b052a91c92') {
            return;
        } else {
            // 执行接入方小程序原本的逻辑
        }
    },
    
    ```

